@@ -158,12 +158,14 @@ def start_master_api_node(cfg: PlotmanConfig):
         )
 
         appcli = web.Application([
-            (r"monitor/(.*)", web.StaticFileHandler, dict(path=get_dash_v1(), default_filename="index.html")),
             (r"/report", NodeHandle),
             (r"/nodes", DashSimpleListNodes),
-            (r"/api/v1", ApiV1Review)
+            (r"/api/v1", ApiV1Review),
+            (r"/monitor/(.*)", web.StaticFileHandler, dict(path=get_dash_v1(), default_filename="index.html"))
         ], **settings)
 
+        print(f"Serve nuxt path {get_dash_v1()} and set default entry point as index.html")
+
         http_server = httpserver.HTTPServer(appcli)
         http_server.listen(cfg.apis.port)
         ioloop.IOLoop.current().start()
